==> highres-1.0.2.tar.gz: highres-1.0.2/README.md <==
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
[![LinkedIn][linkedin-shield]][linkedin-url]

<p align="center">
  <a href="https://github.com/dillir07/hires">
    <img src="https://dev-to-uploads.s3.amazonaws.com/i/ud9pn9tdo5txv5mvwppo.png" alt="hires Logo" width="200" height="200">
  </a>

  <h3 align="center">hires</h3>

  <p align="center">
    A script to download hi-resolution images using google search by image feature
    <br />
    <a href="https://github.com/dillir07/hires"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/dillir07/hires">View Demo</a>
    ·
    <a href="https://github.com/dillir07/hires/issues">Report Bug</a>
    ·
    <a href="https://github.com/dillir07/hires/issues">Request Feature</a>
  </p>
</p>

## Table of Contents

- [Table of Contents](#table-of-contents)
- [About The Project](#about-the-project)
  - [Built With](#built-with)
- [Getting Started](#getting-started)
  - [Prerequisites](#prerequisites)
- [Usage](#usage)
- [Roadmap](#roadmap)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)



<!-- ABOUT THE PROJECT -->
## About The Project

<!-- [![Product Name Screen Shot][product-screenshot]](https://example.com) -->

'hires' script to download hi-resolution images using google search by image feature

### Built With

* Python

<!-- GETTING STARTED -->
## Getting Started

To get a local copy up and running follow these simple steps.

### Prerequisites

This is the list things you need to hires and how to install them.

* A browser (Chrome or Firefox or Edge or Safari)
* Webdriver for the browser

### Installation

1. Install hires using pip
```sh
pip install hires
```

<!-- USAGE EXAMPLES -->
## Usage

- If not available already, install a browser such or Chrome or Firefox or Safari or Edge
- First step is to download webdriver for your Browser
  - Chrome: https://chromedriver.chromium.org/downloads
  - Firefox: https://github.com/mozilla/geckodriver/releases
  - Edge: https://developer.microsoft.com/en-us/microsoft-edge/tools/webdriver/
  - Safari: https://developer.apple.com/documentation/webkit/testing_with_webdriver_in_safari

- Add Webdrivers's folder path to system path
- place your images in a folder, ex: C:\users\dr\Pictures\low-res-images\

execute as follows
```bash
C:\>hires C:\users\dr\Pictures\low-res-images
```

## Roadmap

See the [open issues](https://github.com/dillir07/hires/issues) for a list of proposed features (and known issues).

## License

Distributed under the MIT License. See `LICENSE` for more information.

## Contact

Dilli Babu R - [@dillir07](https://twitter.com/dillir07) - dillir07@outlook.com

Project Link: [https://dillir07.github.io/hires](https://dillir07.github.io/hires/)

[contributors-shield]: https://img.shields.io/github/contributors/dillir07/hires?style=flat-square

[contributors-url]: https://github.com/dillir07/Best-README-Template/graphs/contributors

[forks-shield]: https://img.shields.io/github/forks/dillir07/hires?style=flat-square

[forks-url]: https://github.com/dillir07/Best-README-Template/network/members

[stars-shield]: https://img.shields.io/github/stars/dillir07/hires?style=flat-square

[stars-url]: https://github.com/dillir07/Best-README-Template/stargazers

[issues-shield]: https://img.shields.io/github/issues/dillir07/hires?style=flat-square

[issues-url]: https://github.com/dillir07/Best-README-Template/issues

[license-shield]: https://img.shields.io/github/license/dillir07/hires?style=flat-square

[license-url]: https://github.com/dillir07/hires/blob/master/LICENSE

[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=flat-square&logo=linkedin&colorB=555

[linkedin-url]: https://linkedin.com/in/dillir07
[product-screenshot]: images/screenshot.png

==> highres-1.0.4.tar.gz: highres-1.0.4/README.md <==
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
[![LinkedIn][linkedin-shield]][linkedin-url]

<p align="center">
  <a href="https://github.com/dillir07/highres">
    <img src="https://dev-to-uploads.s3.amazonaws.com/i/ud9pn9tdo5txv5mvwppo.png" alt="highres Logo" width="200" height="200">
  </a>

  <h3 align="center">highres</h3>

  <p align="center">
    A script to download hi-resolution images using google search by image feature
    <br />
    <a href="https://github.com/dillir07/highres"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/dillir07/highres">View Demo</a>
    ·
    <a href="https://github.com/dillir07/highres/issues">Report Bug</a>
    ·
    <a href="https://github.com/dillir07/highres/issues">Request Feature</a>
  </p>
</p>

## Table of Contents

- [Table of Contents](#table-of-contents)
- [About The Project](#about-the-project)
  - [Built With](#built-with)
- [Getting Started](#getting-started)
  - [Prerequisites](#prerequisites)
- [Usage](#usage)
- [Roadmap](#roadmap)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)



<!-- ABOUT THE PROJECT -->
## About The Project

<!-- [![Product Name Screen Shot][product-screenshot]](https://example.com) -->

'highres' script to download hi-resolution images using google search by image feature

### Built With

* Python

<!-- GETTING STARTED -->
## Getting Started

To get a local copy up and running follow these simple steps.

### Prerequisites

This is the list things you need to highres and how to install them.

* A browser (Chrome or Firefox or Edge or Safari)
* Webdriver for the browser

### Installation

1. Install highres using pip
```sh
pip install highres
```

<!-- USAGE EXAMPLES -->
## Usage

- If not available already, install a browser such or Chrome or Firefox or Safari or Edge
- First step is to download webdriver for your Browser
  - Chrome: https://chromedriver.chromium.org/downloads
  - Firefox: https://github.com/mozilla/geckodriver/releases
  - Edge: https://developer.microsoft.com/en-us/microsoft-edge/tools/webdriver/
  - Safari: https://developer.apple.com/documentation/webkit/testing_with_webdriver_in_safari

- Add Webdrivers's folder path to system path
- place your images in a folder, ex: C:\users\dr\Pictures\low-res-images\

execute as follows
```bash
C:\>highres C:\users\dr\Pictures\low-res-images
```

## Roadmap

See the [open issues](https://github.com/dillir07/highres/issues) for a list of proposed features (and known issues).

## License

Distributed under the MIT License. See `LICENSE` for more information.

## Contact

Dilli Babu R - [@dillir07](https://twitter.com/dillir07) - dillir07@outlook.com

Project Link: [https://dillir07.github.io/highres](https://dillir07.github.io/highres/)

[contributors-shield]: https://img.shields.io/github/contributors/dillir07/highres?style=flat-square

[contributors-url]: https://github.com/dillir07/Best-README-Template/graphs/contributors

[forks-shield]: https://img.shields.io/github/forks/dillir07/highres?style=flat-square

[forks-url]: https://github.com/dillir07/Best-README-Template/network/members

[stars-shield]: https://img.shields.io/github/stars/dillir07/highres?style=flat-square

[stars-url]: https://github.com/dillir07/Best-README-Template/stargazers

[issues-shield]: https://img.shields.io/github/issues/dillir07/highres?style=flat-square

[issues-url]: https://github.com/dillir07/Best-README-Template/issues

[license-shield]: https://img.shields.io/github/license/dillir07/highres?style=flat-square

[license-url]: https://github.com/dillir07/highres/blob/master/LICENSE

[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=flat-square&logo=linkedin&colorB=555

[linkedin-url]: https://linkedin.com/in/dillir07
[product-screenshot]: images/screenshot.png
